==> haskell-servant-server-0.20.3.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-4ifWZ3LXLoLFsgPLrPy73E
key:                  servant-server-0.20.3.0-4ifWZ3LXLoLFsgPLrPy73E
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  0e0bf4244d483b6ca01de16899679543
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-4ifWZ3LXLoLFsgPLrPy73E
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 constraints-0.14.2-1KE1LtvelHoEkOUj9iZnlO
    containers-0.6.7 exceptions-0.10.5 filepath-1.4.2.2
    http-api-data-0.6.1-2TUoEeekJvj7bMTmfNTM09
    http-media-0.8.1.1-ED6TwhQl5UP62bsOUkVBr3
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    monad-control-1.0.3.1-GNg7rMkJjzvFBwRXF4awMq mtl-2.2.2
    network-3.1.4.0-K2TPJT2eLM87X4awxEjMbA
    resourcet-1.2.6-AJ1OoWHoMXT5AEQka8SZQl
    servant-0.20.3.0-GoDzgAX79y3uyRklT1hd7
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-76fAVaE3RLCLSxRoiGfG0c
    wai-3.2.4-CKkA8Aq5NeD7z1ZAcTjQU2
    wai-app-static-3.1.9-FQMLgcDLTeWGqloUAQs32F
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.20.3.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-F70hw924dVX11PFVE3P8JQ
key:                  servant-server-0.20.3.0-F70hw924dVX11PFVE3P8JQ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  98113ce8b966737b208f97858d32e1f3
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-F70hw924dVX11PFVE3P8JQ
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 constraints-0.14.2-1KE1LtvelHoEkOUj9iZnlO
    containers-0.6.7 exceptions-0.10.5 filepath-1.4.2.2
    http-api-data-0.6.1-2TUoEeekJvj7bMTmfNTM09
    http-media-0.8.1.1-ED6TwhQl5UP62bsOUkVBr3
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    monad-control-1.0.3.1-GNg7rMkJjzvFBwRXF4awMq mtl-2.2.2
    network-3.1.4.0-K2TPJT2eLM87X4awxEjMbA
    resourcet-1.2.6-AJ1OoWHoMXT5AEQka8SZQl
    servant-0.20.3.0-GoDzgAX79y3uyRklT1hd7
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-76fAVaE3RLCLSxRoiGfG0c
    wai-3.2.4-CKkA8Aq5NeD7z1ZAcTjQU2
    wai-app-static-3.1.9-7NtjkiT66cZCfLD6EBIZrO
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
